traitsui\.tests\.editors\.test\_instance\_editor module
=======================================================

.. automodule:: traitsui.tests.editors.test_instance_editor
    :members:
    :undoc-members:
    :show-inheritance:
